@@ -25,8 +25,6 @@
  *
  * END_COMMON_COPYRIGHT_HEADER */
 
-
-
 #include "xdgmenu.h"
 #include "xdgmenu_p.h"
 #include "xdgmenureader.h"
@@ -40,12 +38,12 @@
 #include <QtXml/QDomElement>
 #include <QtXml/QDomNamedNodeMap>
 #include <QFile>
-#include <QSettings>
 #include <QFileInfo>
+#include <QFileSystemWatcher>
+#include <QSettings>
 #include <QDir>
 #include <QHash>
 #include <QLocale>
-#include <QFileSystemWatcher>
 #include <QTranslator>
 #include <QCoreApplication>
 #include <QCryptographicHash>
@@ -55,36 +53,14 @@
 void installTranslation(const QString &name);
 bool isParent(const QDomElement& parent, const QDomElement& child);
 
-void installTranslation(const QString &name)
-{
-    static bool alreadyLoaded = false;
 
-    if (alreadyLoaded)
-        return;
-
-    QString locale = QLocale::system().name();
-    QTranslator *translator = new QTranslator(qApp);
-    translator->load(QString("%1/%2_%3.qm").arg(TRANSLATIONS_DIR, name, locale));
-
-    QCoreApplication::installTranslator(translator);
-    alreadyLoaded = true;
-}
-
-
-/************************************************
-
- ************************************************/
 XdgMenu::XdgMenu(QObject *parent) :
     QObject(parent),
     d_ptr(new XdgMenuPrivate(this))
 {
-    installTranslation("libqtxdg");
 }
 
 
-/************************************************
-
- ************************************************/
 XdgMenu::~XdgMenu()
 {
     Q_D(XdgMenu);
@@ -92,9 +68,6 @@ XdgMenu::~XdgMenu()
 }
 
 
-/************************************************
-
- ************************************************/
 XdgMenuPrivate::XdgMenuPrivate(XdgMenu *parent):
     mOutDated(true),
     q_ptr(parent)
@@ -111,9 +84,6 @@ XdgMenuPrivate::XdgMenuPrivate(XdgMenu *parent):
 }
 
 
-/************************************************
-
- ************************************************/
 const QString XdgMenu::logDir() const
 {
     Q_D(const XdgMenu);
@@ -121,9 +91,6 @@ const QString XdgMenu::logDir() const
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenu::setLogDir(const QString& directory)
 {
     Q_D(XdgMenu);
@@ -131,9 +98,6 @@ void XdgMenu::setLogDir(const QString& directory)
 }
 
 
-/************************************************
-
- ************************************************/
 const QDomDocument XdgMenu::xml() const
 {
     Q_D(const XdgMenu);
@@ -141,9 +105,6 @@ const QDomDocument XdgMenu::xml() const
 }
 
 
-/************************************************
-
- ************************************************/
 QString XdgMenu::menuFileName() const
 {
     Q_D(const XdgMenu);
@@ -151,28 +112,26 @@ QString XdgMenu::menuFileName() const
 }
 
 
-/************************************************
-
- ************************************************/
 QStringList XdgMenu::environments()
 {
     Q_D(XdgMenu);
     return d->mEnvironments;
 }
 
+
 void XdgMenu::setEnvironments(const QStringList &envs)
 {
     Q_D(XdgMenu);
     d->mEnvironments = envs;
 }
+
+
 void XdgMenu::setEnvironments(const QString &env)
 {
     setEnvironments(QStringList() << env);
 }
 
-/************************************************
 
- ************************************************/
 const QString XdgMenu::errorString() const
 {
     Q_D(const XdgMenu);
@@ -180,9 +139,6 @@ const QString XdgMenu::errorString() const
 }
 
 
-/************************************************
-
- ************************************************/
 bool XdgMenu::read(const QString& menuFileName)
 {
     Q_D(XdgMenu);
@@ -241,9 +197,6 @@ bool XdgMenu::read(const QString& menuFileName)
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenu::save(const QString& fileName)
 {
     Q_D(const XdgMenu);
@@ -279,9 +232,6 @@ void XdgMenuPrivate::load(const QString& fileName)
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::saveLog(const QString& logFileName)
 {
     Q_Q(XdgMenu);
@@ -290,9 +240,6 @@ void XdgMenuPrivate::saveLog(const QString& logFileName)
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::mergeMenus(QDomElement& element)
 {
     QHash<QString, QDomElement> menus;
@@ -333,9 +280,6 @@ void XdgMenuPrivate::mergeMenus(QDomElement& element)
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::simplify(QDomElement& element)
 {
     MutableDomElementIterator it(element);
@@ -393,9 +337,6 @@ void XdgMenuPrivate::simplify(QDomElement& element)
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::prependChilds(QDomElement& srcElement, QDomElement& destElement)
 {
     MutableDomElementIterator it(srcElement);
@@ -419,9 +360,6 @@ void XdgMenuPrivate::prependChilds(QDomElement& srcElement, QDomElement& destEle
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::appendChilds(QDomElement& srcElement, QDomElement& destElement)
 {
     MutableDomElementIterator it(srcElement);
@@ -487,9 +425,6 @@ QDomElement XdgMenu::findMenu(QDomElement& baseElement, const QString& path, boo
 }
 
 
-/************************************************
-
- ************************************************/
 bool isParent(const QDomElement& parent, const QDomElement& child)
 {
     QDomNode  n = child;
@@ -574,9 +509,6 @@ void XdgMenuPrivate::deleteDeletedMenus(QDomElement& element)
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::processDirectoryEntries(QDomElement& element, const QStringList& parentDirs)
 {
     QStringList dirs;
@@ -631,9 +563,6 @@ void XdgMenuPrivate::processDirectoryEntries(QDomElement& element, const QString
 }
 
 
-/************************************************
-
- ************************************************/
 bool XdgMenuPrivate::loadDirectoryFile(const QString& fileName, QDomElement& element)
 {
     XdgDesktopFile file;
@@ -653,9 +582,6 @@ bool XdgMenuPrivate::loadDirectoryFile(const QString& fileName, QDomElement& ele
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::processApps(QDomElement& element)
 {
     Q_Q(XdgMenu);
@@ -664,9 +590,6 @@ void XdgMenuPrivate::processApps(QDomElement& element)
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::deleteEmpty(QDomElement& element)
 {
     MutableDomElementIterator it(element, "Menu");
@@ -686,9 +609,6 @@ void XdgMenuPrivate::deleteEmpty(QDomElement& element)
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::processLayouts(QDomElement& element)
 {
     XdgMenuLayoutProcessor proc(element);
@@ -696,9 +616,6 @@ void XdgMenuPrivate::processLayouts(QDomElement& element)
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::fixSeparators(QDomElement& element)
 {
 
@@ -768,9 +685,6 @@ QString XdgMenu::getMenuFileName(const QString& baseName)
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenu::addWatchPath(const QString &path)
 {
     Q_D(XdgMenu);
@@ -785,9 +699,6 @@ void XdgMenu::addWatchPath(const QString &path)
 }
 
 
-/************************************************
-
- ************************************************/
 bool XdgMenu::isOutDated() const
 {
     Q_D(const XdgMenu);
@@ -795,9 +706,6 @@ bool XdgMenu::isOutDated() const
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::rebuild()
 {
     Q_Q(XdgMenu);
@@ -812,9 +720,6 @@ void XdgMenuPrivate::rebuild()
 }
 
 
-/************************************************
-
- ************************************************/
 void XdgMenuPrivate::clearWatcher()
 {
     QStringList sl;
